#pragma interface
#ifndef INTERNAL_H
#define INTERNAL_H

#ifndef MODAPI_H
	#include "modapi.h"
#endif


class M_DIALOG_INTERNAL {
	friend class M_DIALOG;
	friend class M_DIALOG_LISTE;
	M_FIELD_COMBO *combo;
	M_FIELD_COMBO_MANY *fmany;
	M_FIELD_ENUM *fenum;
	M_FIELD_LIST *list;
	M_FIELD_CLIST *clist;
	M_FIELD_BUTTON_TEXT *btext;
	M_FIELD_BUTTON_ICON *bicon;
	/*~PROTOBEG~ M_DIALOG_INTERNAL */
public:
	M_DIALOG_INTERNAL (void);
	~M_DIALOG_INTERNAL (void);
	/*~PROTOEND~ M_DIALOG_INTERNAL */
};

#endif

